@@ -4,10 +4,10 @@ use swc_css_ast::*;
 use swc_css_visit::VisitMutWith;
 
 use self::compress::{
-    alpha_value::compress_alpha_value, angle::compress_angle, declaration::compress_declaration,
-    easing_function::compress_easing_function, empty::compress_empty,
-    frequency::compress_frequency, keyframes::compress_keyframes, length::compress_length,
-    selector::compress_selector, time::compress_time,
+    alpha_value::compress_alpha_value, angle::compress_angle, at_rule::compress_at_rule,
+    declaration::compress_declaration, easing_function::compress_easing_function,
+    empty::compress_empty, frequency::compress_frequency, keyframes::compress_keyframes,
+    length::compress_length, selector::compress_selector, time::compress_time,
     transform_function::compress_transform_function, unicore_range::compress_unicode_range,
     url::compress_url,
 };
@@ -28,5 +28,5 @@ pub fn minify(stylesheet: &mut Stylesheet) {
     stylesheet.visit_mut_with(&mut compress_declaration());
     stylesheet.visit_mut_with(&mut compress_selector());
     stylesheet.visit_mut_with(&mut compress_keyframes());
-    stylesheet.visit_mut_with(&mut compress_selector());
+    stylesheet.visit_mut_with(&mut compress_at_rule());
 }
